%define tar_ver	%(echo %{version}|sed -e 's/\\./\\_/g')

Summary:	Network Traffic sniffer, with pattern matching like grep
Name:		ngrep
Version:	1.47
Release:	%mkrel 6
License:	BSD
Group:		Networking/Other
URL:		https://github.com/jpr5/ngrep
Source0:	https://github.com/jpr5/ngrep/archive/V1_47/%{name}-%{tar_ver}.tar.gz
Patch0:		ngrep-1.47-upstream-fixes.patch
Patch1:		ngrep-1.47-pcre2.patch
Patch2:		ngrep-tcpkill-c99.patch
BuildRequires:	gcc
BuildRequires:	pcap-devel
BuildRequires:	net2-devel
BuildRequires:	pkgconfig(libpcre2-8)

%description
ngrep strives to provide most of GNU grep's common features,
applying them to the network layer.  ngrep is a pcap-aware tool
that will allow you to specify extended regular or hexadecimal
expressions to match against data payloads of packets. It
currently recognizes TCP, UDP and ICMP across Ethernet, PPP, SLIP,
FDDI, Token Ring and null interfaces, and understands bpf filter
logic in the same fashion as more common packet sniffing tools,
such as tcpdump and snoop.

%prep
%autosetup -p1 -n %{name}-%{tar_ver}

# Make sure not to be using bundled libs
rm -r regex-0.12

# fix build on aarch64
cp -af %{_rpmconfigdir}/%{_real_vendor}/config.{guess,sub} .

%build
autoreconf -vfi

%configure \
    --enable-pcre2 \
    --enable-ipv6 \
    --with-pcap-includes=%{_includedir}/pcap \
    --enable-tcpkill \
    --disable-pcap-restart

%make_build STRIPFLAG=

%install
make install DESTDIR=%{buildroot}

%files
%doc CHANGES CREDITS EXAMPLES.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man8/*


%changelog
* Mon Sep 30 2024 daviddavid <daviddavid> 1.47-6.mga10
+ Revision: 2102143
- add patch to fix build with GCC 14

* Fri Apr 14 2023 daviddavid <daviddavid> 1.47-5.mga9
+ Revision: 1952929
- switch to pcre2 (mga#31791)

* Tue Mar 29 2022 umeabot <umeabot> 1.47-4.mga9
+ Revision: 1831556
- Mageia 9 Mass Rebuild

* Sun Jul 05 2020 joequant <joequant> 1.47-3.mga8
+ Revision: 1602135
- remove arm workaround

* Fri Feb 14 2020 umeabot <umeabot> 1.47-2.mga8
+ Revision: 1521873
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jan 03 2019 daviddavid <daviddavid> 1.47-1.mga7
+ Revision: 1348906
- new version: 1.47
- update URL and Source URL

* Sun Sep 23 2018 umeabot <umeabot> 1.45-17.mga7
+ Revision: 1299741
- Mageia 7 Mass Rebuild

* Sun Jun 10 2018 wally <wally> 1.45-16.mga7
+ Revision: 1236194
- fix build on aarch64

* Thu Aug 18 2016 daviddavid <daviddavid> 1.45-15.mga6
+ Revision: 1046956
- disable pcap restart to fix build against new libpcap 1.8.0

* Fri Feb 12 2016 umeabot <umeabot> 1.45-14.mga6
+ Revision: 956260
- Mageia 6 Mass Rebuild

* Mon Oct 19 2015 danf <danf> 1.45-13.mga6
+ Revision: 892796
- Added nostrip patch to stop stripping binary

* Wed Oct 15 2014 umeabot <umeabot> 1.45-12.mga5
+ Revision: 748969
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.45-11.mga5
+ Revision: 682883
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.45-10.mga4
+ Revision: 508273
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 30 2012 pterjan <pterjan> 1.45-8.mga3
+ Revision: 336306
- Add a patch to fix build when some options are given to make

* Sat Apr 30 2011 sander85 <sander85> 1.45-7.mga1
+ Revision: 93842
- bump release for upgrading from mdv2010.{1,2}

* Wed Mar 16 2011 steletch <steletch> 1.45-1.mga1
+ Revision: 72745
- Clean spec file
- imported package ngrep


* Mon Sep 14 2009 Thierry Vignaud <tvignaud@mandriva.com> 1.45-6mdv2010.0
+ Revision: 440330
- rebuild

* Thu Oct 30 2008 Oden Eriksson <oeriksson@mandriva.com> 1.45-5mdv2009.1
+ Revision: 298739
- bump release
- bunzip the patch

* Wed Oct 29 2008 Oden Eriksson <oeriksson@mandriva.com> 1.45-4mdv2009.1
+ Revision: 298624
- fix build
- rebuilt against libpcap-1.0.0

* Tue Jul 29 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.45-3mdv2009.0
+ Revision: 253951
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.45-1mdv2008.1
+ Revision: 136631
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon May 21 2007 Antoine Ginies <aginies@mandriva.com> 1.45-1mdv2008.0
+ Revision: 29491
- release 1.45
- Import ngrep



* Tue Sep 12 2006 Oden Eriksson <oeriksson@mandriva.com> 1.44-3mdv2007.0
- rebuild

* Wed Jul 13 2005 Oden Eriksson <oeriksson@mandriva.com> 1.44-2mdk
- rebuilt against new libpcap-0.9.1 (aka. a "play safe" rebuild)

* Tue Jul 05 2005 Oden Eriksson <oeriksson@mandriva.com> 1.44-1mdk
- 1.44
- drop P1, it won't apply anymore

* Thu Jun 16 2005 Oden Eriksson <oeriksson@mandriva.com> 1.43-2mdk
- fix changelog mismatch

* Thu Jun 16 2005 Oden Eriksson <oeriksson@mandriva.com> 1.43-1mdk
- 1.43
- rediff P0 & P1, drop P2
- fix deps

* Fri Jun 03 2005 Oden Eriksson <oeriksson@mandriva.com> 1.41-3mdk
- rebuild

* Tue Mar 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.41-2mdk
- fix build with new libpcap (P2)
- use %%make macro
- compile regex with $RPM_OPT_FLAGS

* Sun Jan 04 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.41-1mdk
- 1.41
- drop explicit library dependency
- fix buildrequires (lib64..)
- fix compile (P1)
- cosmetics

* Thu Jan 16 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 1.40.1-3mdk
- build release

* Sun Aug  4 2002 Oden Eriksson <oden.eriksson@kvikkjokk.net> 1.40.1-2mdk
- rebuilt with gcc-3.2

* Sun Jun  9 2002 Oden Eriksson <oden.eriksson@kvikkjokk.net> 1.40.1-1mdk
- initial cooker contrib
- added P0
